@@ -7,12 +7,16 @@ from shop.addressmodel.models import Country, Address
 #    pass
 #admin.site.register(Client, ClientAdmin)
 
+
 class CountryAdmin(ModelAdmin):
     pass
-    
-admin.site.register(Country, CountryAdmin)
+
 
 class AddressAdmin(ModelAdmin):
-    list_display = ('name', 'address','address2', 'zip_code', 'city', 'country',
-                    'user_shipping', 'user_billing')
-admin.site.register(Address, AddressAdmin)
\ No newline at end of file
+    list_display = (
+        'name', 'address', 'address2', 'zip_code', 'city', 'country',
+        'user_shipping', 'user_billing')
+
+
+admin.site.register(Address, AddressAdmin)
+admin.site.register(Country, CountryAdmin)
