@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from django.utils.translation import ugettext_lazy as _
-from shop.models.defaults.bases import BaseCart
+from shop.models_bases import BaseCart
+
 
 class Cart(BaseCart):
     class Meta(object):
