@@ -5,8 +5,9 @@ from django.conf import settings
 from django.conf.urls.defaults import patterns, url
 from django.shortcuts import render_to_response
 from django.template import RequestContext
+from django.utils.translation import ugettext_lazy as _
 
-from shop.util.decorators import on_method, shop_login_required
+from shop.util.decorators import on_method, shop_login_required, order_required
 
 
 class FlatRateShipping(object):
@@ -16,14 +17,15 @@ class FlatRateShipping(object):
     """
     url_namespace = 'flat'
     backend_name = 'Flat rate'
-    
+    backend_verbose_name = _('Flat rate')
 
     def __init__(self, shop):
-        self.shop = shop # This is the shop reference, it allows this backend
+        self.shop = shop  # This is the shop reference, it allows this backend
         # to interact with it in a tidy way (look ma', no imports!)
         self.rate = getattr(settings, 'SHOP_SHIPPING_FLAT_RATE', '10')
 
     @on_method(shop_login_required)
+    @on_method(order_required)
     def view_process_order(self, request):
         """
         A simple (not class-based) view to process an order.
@@ -31,7 +33,8 @@ class FlatRateShipping(object):
         This will be called by the selection view (from the template) to do the
         actual processing of the order (the previous view displayed a summary).
 
-        It calls shop.finished() to go to the next step in the checkout process.
+        It calls shop.finished() to go to the next step in the checkout
+        process.
         """
         self.shop.add_shipping_costs(self.shop.get_order(request),
                                      'Flat shipping',
@@ -40,16 +43,16 @@ class FlatRateShipping(object):
         # That's an HttpResponseRedirect
 
     @on_method(shop_login_required)
+    @on_method(order_required)
     def view_display_fees(self, request):
         """
         A simple, normal view that displays a template showing how much the
         shipping will be (it's an example, alright)
         """
         ctx = {}
-        ctx.update({'shipping_costs':Decimal(self.rate)})
-        return render_to_response('shop/shipping/flat_rate/display_fees.html', ctx,
-                                  context_instance=RequestContext(request))
-
+        ctx.update({'shipping_costs': Decimal(self.rate)})
+        return render_to_response('shop/shipping/flat_rate/display_fees.html',
+            ctx, context_instance=RequestContext(request))
 
     def get_urls(self):
         """
@@ -60,4 +63,3 @@ class FlatRateShipping(object):
             url(r'^process/$', self.view_process_order, name='flat_process'),
         )
         return urlpatterns
-
