@@ -58,3 +58,10 @@ class Products(InclusionTag):
         context.update({'products': objects, })
         return context
 register.tag(Products)
+
+def priceformat(price):
+    FORMAT = '%0.2f'
+    if not price:
+        return ''
+    return FORMAT % price
+register.filter(priceformat)
