@@ -12,6 +12,7 @@ from shop.models.cartmodel import Cart
 from shop.models.productmodel import Product
 from shop.tests.utils.context_managers import SettingsOverride
 
+
 class CarModifierUsingStatePassing(BaseCartModifier):
     """
     A test cart modifier that uses the state variable to pass things around
@@ -19,19 +20,21 @@ class CarModifierUsingStatePassing(BaseCartModifier):
     def process_cart_item(self, cart_item, state):
         state['TEST'] = 'VALID'
         return cart_item
-        
+
     def process_cart(self, cart, state):
         result = state['TEST']
         assert result == 'VALID'
         return cart
 
+
 class CartModifiersTestCase(TestCase):
-    
+
     PRODUCT_PRICE = Decimal('100')
-    
+
     def setUp(self):
-        cart_modifiers_pool.USE_CACHE=False
-        self.user = User.objects.create(username="test", email="test@example.com")
+        cart_modifiers_pool.USE_CACHE = False
+        self.user = User.objects.create(username="test",
+            email="test@example.com")
         self.product = Product()
         self.product.name = "TestPrduct"
         self.product.slug = "TestPrduct"
@@ -44,21 +47,22 @@ class CartModifiersTestCase(TestCase):
         self.cart = Cart()
         self.cart.user = self.user
         self.cart.save()
-    
+
     def test_01_cart_modifier_pool_loads_modifiers_properly(self):
         """
         Let's add a price modifier to the settings, then load it,
         then call a method on it to make sure it works.
         """
-        MODIFIERS = ['shop.cart.modifiers.tax_modifiers.TenPercentGlobalTaxModifier']
+        MODIFIERS = [
+            'shop.cart.modifiers.tax_modifiers.TenPercentGlobalTaxModifier']
         with SettingsOverride(SHOP_CART_MODIFIERS=MODIFIERS):
             thelist = modifiers_pool.cart_modifiers_pool.get_modifiers_list()
             self.assertEqual(len(thelist), 1)
             instance = thelist[0]
-            self.assertTrue(hasattr(instance,'TAX_PERCENTAGE'))
-            
+            self.assertTrue(hasattr(instance, 'TAX_PERCENTAGE'))
+
     def test_02_cart_modifiers_pool_handles_wrong_path(self):
-        MODIFIERS = ['shop2.cart.modifiers.tax_modifiers'] # wrong path
+        MODIFIERS = ['shop2.cart.modifiers.tax_modifiers']  # wrong path
         with SettingsOverride(SHOP_CART_MODIFIERS=MODIFIERS):
             raised = False
             try:
@@ -66,7 +70,7 @@ class CartModifiersTestCase(TestCase):
             except:
                 raised = True
             self.assertTrue(raised)
-            
+
     def test_03_cart_modifiers_pool_handles_wrong_module(self):
         MODIFIERS = ['shop.cart.modifiers.tax_modifiers.IdontExist']
         with SettingsOverride(SHOP_CART_MODIFIERS=MODIFIERS):
@@ -76,7 +80,7 @@ class CartModifiersTestCase(TestCase):
             except ImproperlyConfigured:
                 raised = True
             self.assertTrue(raised)
-            
+
     def test_03_cart_modifiers_pool_handles_not_a_path(self):
         MODIFIERS = ['shop']
         with SettingsOverride(SHOP_CART_MODIFIERS=MODIFIERS):
@@ -86,20 +90,21 @@ class CartModifiersTestCase(TestCase):
             except ImproperlyConfigured:
                 raised = True
             self.assertTrue(raised)
-            
+
     def test_state_is_passed_around_properly(self):
         MODIFIERS = ['shop.tests.cart_modifiers.CarModifierUsingStatePassing']
         with SettingsOverride(SHOP_CART_MODIFIERS=MODIFIERS):
             self.cart.add_product(self.product)
             self.cart.save()
-            self.cart.update() # This should raise if the state isn't passed
+            self.cart.update()  # This should raise if the state isn't passed
+
 
 class TenPercentPerItemTaxModifierTestCase(TestCase):
 
     class MockItem(object):
         """ A simple mock object to assert the tax modifier works properly"""
         def __init__(self):
-            self.line_subtotal = 100 # Makes testing easy
+            self.line_subtotal = 100  # Makes testing easy
             self.current_total = self.line_subtotal
             self.extra_price_fields = []
 
@@ -108,7 +113,7 @@ class TenPercentPerItemTaxModifierTestCase(TestCase):
         item = self.MockItem()
         field = modifier.get_extra_cart_item_price_field(item)
         self.assertTrue(field[1] == Decimal('10'))
-    
+
     def test_tax_amount_is_correct_after_modifier(self):
         modifier = TenPercentPerItemTaxModifier()
         item = self.MockItem()
@@ -117,4 +122,3 @@ class TenPercentPerItemTaxModifierTestCase(TestCase):
         item.current_total = item.current_total + previous_option[1]
         field = modifier.get_extra_cart_item_price_field(item)
         self.assertTrue(field[1] == Decimal('11'))
-    
